pub enum BridgeError {
UnknownDataCon(DataConId),
UnknownDataConName(String),
ArityMismatch {
con: DataConId,
expected: usize,
got: usize,
},
TypeMismatch {
expected: String,
got: String,
},
UnsupportedType(String),
}Expand description
Errors that can occur when bridging between Rust types and Core Values.
Variants
UnknownDataCon(DataConId)
The DataConId was not found in the DataConTable.
UnknownDataConName(String)
The DataConId was found, but it has an unexpected name.
ArityMismatch
The number of fields in a constructor does not match the expected arity.
Fields
TypeMismatch
The value has an unexpected type (e.g., expected a Literal, got a Con).
Fields
UnsupportedType(String)
The type is not supported by the bridge.